/* -*-c-*-
 *
 * Utilities for the client and the server
 *
 * (c) 2001 Straylight/Edgeware
 */

/*----- Licensing notice --------------------------------------------------*
 *
 * This file is part of Trivial IP Encryption (TrIPE).
 *
 * TrIPE is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * TrIPE is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with TrIPE; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef UTIL_H
#define UTIL_H

#ifndef CONFIG_H
#  include "config.h"
#endif

#include <sys/types.h>

#ifdef __cplusplus
  extern "C" {
#endif

/*----- Functions provided ------------------------------------------------*/

/* --- @u_quotify@ --- *
 *
 * Arguments:	@dstr *d@ = where to write the answer
 *		@const char *p@ = string to quotify
 *
 * Returns:	---
 *
 * Use:		Quotes the given string if necessary, according to our
 *		quoting rules.
 */

extern void u_quotify(dstr */*d*/, const char */*p*/);

/* --- @u_getuser@ --- *
 *
 * Arguments:	@const char *name@ = user name or id requested
 *		@gid_t *gg@ = where to store corresponding gid
 *
 * Returns:	Corresponding uid.
 *
 * Use:		Resolves a user name into a uid.  Dies on failure; suitable
 *		for use in argument parsing.
 */

extern uid_t u_getuser(const char */*name*/, gid_t */*gg*/);

/* --- @u_getgroup@ --- *
 *
 * Arguments:	@const char *name@ = user name or id requested
 *
 * Returns:	Corresponding gid.
 *
 * Use:		Resolves a group name into a gid.  Dies on failure; suitable
 *		for use in argument parsing.
 */

extern gid_t u_getgroup(const char */*name*/);

/* --- @u_setugid@ --- *
 *
 * Arguments:	@uid_t u@ = user to set
 *		@gid_t g@ = group to set
 *
 * Returns:	---
 *
 * Use:		Sets user and group to the given values; aborts on failure.
 */

extern void u_setugid(uid_t /*u*/, gid_t /*g*/);

/*----- That's all, folks -------------------------------------------------*/

#ifdef __cplusplus
  }
#endif

#endif
